/* ***** BEGIN LICENSE BLOCK *****
 *   Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is ThumbsDown.
 *
 * The Initial Developer of the Original Code is
 * Atte Kemppilä.
 * Portions created by the Initial Developer are Copyright (C) 2008
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 * 
 * ***** END LICENSE BLOCK ***** */


function MatcherPage() // extend WizardPage
{
    var depends = "selected linkUrlTokens script";
    WizardPage.call(this, depends);
}

MatcherPage.prototype =
{
    get matcher() { return $("tbox_matcher") },
    
    onPageShow: function()
    {
        if (this.dirty.selected)
        {
            var rlbox = $("rlbox_matcher");
            while (rlbox.itemCount > 0)
                rlbox.removeItemAt(0);
            for each (var thumbnail in model.selected)
                rlbox.appendItem(thumbnail.anchor.link);
        }
        
        if (this.dirty.linkUrlTokens || this.dirty.script)
        {
            var matcher = ((model.mode == MODE_MODIFY) ? model.script.matcher : scriptWizard.getMatcher(model.linkUrlTokens));
            this.matcher.defaultValue = matcher;
            this.matcher.reset();
        }
        
        if (this.dirty.page)
        {
            this._updateMatcher();
            this._updateButtons();
        }
    },
    
    onMatcherInput: function()
    {
        if (this.updateTimer)
            this.updateTimer.cancel();
        
        this.updateTimer = callLater(INPUT_DELAY, this, this._updateMatcherInput);
        
        this._updateButtons();
        wizard.updateWizardButtons();
    },
    
    resetMatcher: function()
    {
        this.matcher.reset();
        this._updateMatcher();
        this._updateButtons();
        wizard.updateWizardButtons();
    },
    
    canAdvance: function()
    {
        if (this.updateTimer)
            return false;
        
        return $("rlbox_matcher").match;
    },
    
    _updateMatcherInput: function()
    {
        this._updateMatcher();
        wizard.updateWizardButtons();
    },
    
    _updateMatcher: function()
    {
        if (page != pages.matcher)
            return;
        
        if (this.updateTimer)
        {
            this.updateTimer.cancel();
            delete this.updateTimer;
        }
        
        $("rlbox_matcher").pattern = "^" + this.matcher.value + "$";
    },
    
    _updateButtons: function()
    {
        $("btn_matcher_reset").disabled = (this.matcher.value == this.matcher.defaultValue);
    },
    
    onPageAdvanced: function()
    {
        model.matcher = this.matcher.value;
        
        if (model.type == TYPE_DIRECT)
            return wizard.advance("script");
        
        return wizard.advance("type");
    }
}

extend(MatcherPage, WizardPage);

pages.matcher = new MatcherPage();
